# Contributing to the Root Signals SDK

The following is a set of guidelines for contributing to this project. These are mostly guidelines, not rules. Use your best judgment, and feel free to propose changes to this document in a pull request.

## How Can I Contribute?

### Reporting Bugs

Before creating bug reports, please check the existing issues as you might find out that you don't need to create one. When you are creating a bug report, please include as many details as possible:

* Your SDK version
* Python version
* Describe the exact steps which reproduce the problem
* Provide specific examples to demonstrate the steps


### Suggesting Enhancements

Enhancement suggestions are tracked as GitHub issues. Any suggestions are welcome!

### Code Changes

Please create a pull request for any changes you want to contribute.

## Development Setup

Use hatch to install the dependencies and run the tests.

Check the Makefile for other development commands.
